==> bacula_7.0.5+dfsg.orig.tar.xz: bacula-7.0.5+dfsg/src/lib/lib.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2014 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from many
   others, a complete list can be found in the file AUTHORS.

   You may use this file and others of this release according to the
   license defined in the LICENSE file, which includes the Affero General
   Public License, v3.0 ("AGPLv3") and some additional permissions and
   terms pursuant to its AGPLv3 Section 7.

   Bacula® is a registered trademark of Kern Sibbald.
*/
/*
 *   Library includes for Bacula lib directory
 *
 *   This file contains an include for each library file
 *   that we use within Bacula. bacula.h includes this
 *   file and thus picks up everything we need in lib.
 *
 */

#include "smartall.h"
#include "lockmgr.h"
#include "alist.h"
#include "dlist.h"
#include "rblist.h"
#include "base64.h"
#include "bits.h"
#include "btime.h"
#include "crypto.h"
#include "mem_pool.h"
#include "rwlock.h"
#include "queue.h"
#include "serial.h"
#include "message.h"
#include "openssl.h"
#include "lex.h"
#include "parse_conf.h"
#include "tls.h"
#include "address_conf.h"
#include "bsock.h"
#include "workq.h"
#ifndef HAVE_FNMATCH
#include "fnmatch.h"
#endif
#include "md5.h"
#include "sha1.h"
#include "tree.h"
#include "watchdog.h"
#include "btimers.h"
#include "berrno.h"
#include "bpipe.h"
#include "attr.h"
#include "var.h"
#include "guid_to_name.h"
#include "htable.h"
#include "sellist.h"
#include "protos.h"

==> bacula_7.4.4+dfsg.orig.tar.xz: bacula-7.4.4+dfsg/src/lib/lib.h <==
/*
   Bacula(R) - The Network Backup Solution

   Copyright (C) 2000-2016 Kern Sibbald

   The original author of Bacula is Kern Sibbald, with contributions
   from many others, a complete list can be found in the file AUTHORS.

   You may use this file and others of this release according to the
   license defined in the LICENSE file, which includes the Affero General
   Public License, v3.0 ("AGPLv3") and some additional permissions and
   terms pursuant to its AGPLv3 Section 7.

   This notice must be preserved when any source code is 
   conveyed and/or propagated.

   Bacula(R) is a registered trademark of Kern Sibbald.
*/
/*
 *   Library includes for Bacula lib directory
 *
 *   This file contains an include for each library file
 *   that we use within Bacula. bacula.h includes this
 *   file and thus picks up everything we need in lib.
 *
 */

#include "smartall.h"
#include "lockmgr.h"
#include "alist.h"
#include "dlist.h"
#include "rblist.h"
#include "base64.h"
#include "bits.h"
#include "btime.h"
#include "crypto.h"
#include "mem_pool.h"
#include "rwlock.h"
#include "queue.h"
#include "serial.h"
#include "message.h"
#include "openssl.h"
#include "lex.h"
#include "parse_conf.h"
#include "tls.h"
#include "address_conf.h"
#include "bsock.h"
#include "workq.h"
#ifndef HAVE_FNMATCH
#include "fnmatch.h"
#endif
#include "md5.h"
#include "sha1.h"
#include "tree.h"
#include "watchdog.h"
#include "btimers.h"
#include "berrno.h"
#include "bpipe.h"
#include "attr.h"
#include "var.h"
#include "guid_to_name.h"
#include "htable.h"
#include "sellist.h"
#include "protos.h"
#include "bget_msg.h"
